@@ -10,4 +10,6 @@
         "rg-integration/rg-executable-through-rg-run"
         "rg-integration/rg-recompile"
         "rg-unit/isearch-project"
+        "rg-unit/menu-define-search"
+        "rg-unit/menu-transient-insert"
         )))
